==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebListItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListItemDescription } from "./WebListItemDescription";
/**
 * @hidden
 */
var WebListItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebListItemDescriptionMetadata, _super);
    function WebListItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListItemDescriptionMetadata.b = function (a) {
        if (WebListItemDescriptionMetadata.a == null) {
            WebListItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListItemDescriptionMetadata.c(WebListItemDescriptionMetadata.a);
        }
        if (a.j(WebListItemDescriptionMetadata.a)) {
            return;
        }
        a.y(WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ListItem");
        a.item("__tagNameWC", "String:igc-list-item");
    };
    WebListItemDescriptionMetadata.d = function (a) {
        WebListItemDescriptionMetadata.b(a);
        a.aa("WebListItem", function () { return new WebListItemDescription(); });
        a.z("WebListItem", WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.$t = markType(WebListItemDescriptionMetadata, 'WebListItemDescriptionMetadata');
    WebListItemDescriptionMetadata.a = null;
    return WebListItemDescriptionMetadata;
}(Base));
export { WebListItemDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebListItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListItemDescription } from "./WebListItemDescription";
/**
 * @hidden
 */
var WebListItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebListItemDescriptionMetadata, _super);
    function WebListItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListItemDescriptionMetadata.b = function (a) {
        if (WebListItemDescriptionMetadata.a == null) {
            WebListItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListItemDescriptionMetadata.c(WebListItemDescriptionMetadata.a);
        }
        if (a.k(WebListItemDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ListItem");
        a.item("__tagNameWC", "String:igc-list-item");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebListItemDescriptionMetadata.d = function (a) {
        WebListItemDescriptionMetadata.b(a);
        a.ac("WebListItem", function () { return new WebListItemDescription(); });
        a.ab("WebListItem", WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.$t = markType(WebListItemDescriptionMetadata, 'WebListItemDescriptionMetadata');
    WebListItemDescriptionMetadata.a = null;
    return WebListItemDescriptionMetadata;
}(Base));
export { WebListItemDescriptionMetadata };
